<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:java="java"
	exclude-result-prefixes="fo"
>

	<xsl:output method="xml" version="1.0" omit-xml-declaration="no" indent="no" />

	<xsl:include href="template://Barcode_Template.xsl" />

	<xsl:include href="customVariables://userDefinedInFile_print.properties" />


	<!-- ============================== -->
	<!-- Template: Single Sticker -->
	<!-- ============================== -->

	<xsl:template match="sticker">
		<xsl:choose>
			<xsl:when test="/report/demo = 'true'">
				<fo:block background-image="url('image://FOP_DEMO')" background-position="0,0" background-repeat="repeat" background-color="white" padding="3mm">
					<xsl:call-template name="main_table"></xsl:call-template>
				</fo:block>
			</xsl:when>
			<xsl:otherwise>
				<fo:block padding="3mm">
					<xsl:call-template name="main_table"></xsl:call-template>
				</fo:block>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="main_table">
		<fo:table width="100%">
			<fo:table-column column-width="10mm" />
			<fo:table-column column-width="73.5mm" />
			<fo:table-column column-width="48mm" />
			<fo:table-body>

				<fo:table-row>

					<xsl:choose>
						<xsl:when test="printVerticalSmallLabels = 'true'">
							<fo:table-cell padding="1mm" padding-top="0mm" display-align="center">
								<fo:block>
									<xsl:call-template name="barcode">
										<xsl:with-param name="message" select="trackingCode" />
										<xsl:with-param name="codeType" select="'smallLabel'" />
									</xsl:call-template>
								</fo:block>
								<fo:block font-size="3mm" color="white">
									<xsl:text>.</xsl:text>
								</fo:block>
								<fo:block>
									<xsl:call-template name="barcode">
										<xsl:with-param name="message" select="trackingCode" />
										<xsl:with-param name="codeType" select="'smallLabel'" />
									</xsl:call-template>
								</fo:block>
							</fo:table-cell>
						</xsl:when>
						<xsl:otherwise>
							<xsl:choose>
								<xsl:when test="printVerticalReference1 = 'true'">
									<fo:table-cell padding="1mm" padding-top="0mm">
										<xsl:choose>
											<xsl:when test="string-length(referenceNr1Barcode) &gt; 0 and string-length(referenceNr1Barcode) &lt;= 32">
												<fo:block>
													<xsl:call-template name="barcode">
														<xsl:with-param name="message" select="referenceNr1Barcode" />
														<xsl:with-param name="codeType" select="'referenceNr1'" />
													</xsl:call-template>
												</fo:block>
											</xsl:when>
											<xsl:otherwise>
												<fo:block>
													<xsl:text> </xsl:text>
												</fo:block>
											</xsl:otherwise>
										</xsl:choose>
									</fo:table-cell>
								</xsl:when>
								<xsl:otherwise>
									<fo:table-cell padding="1mm" padding-top="0mm">
										<fo:block>
											<xsl:text> </xsl:text>
										</fo:block>
									</fo:table-cell>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:otherwise>
					</xsl:choose>
					<fo:table-cell>

						<!-- Central column -->
						<fo:block padding="1mm" font-style="normal">
							<fo:table width="100%">
								<fo:table-body>
									<fo:table-row>
										<fo:table-cell>

											<!-- Licensee logo -->
											<fo:block margin-bottom="0.5mm">
												<fo:table width="100%">
													<fo:table-body>
														<fo:table-row>
															<fo:table-cell>
                                <xsl:choose>
                                  <xsl:when test="/report/printLicenseeLogoOnLabel = 'true'">
                                    <fo:block>
                                      <fo:inline padding-right="1mm">
                                        <fo:external-graphic height="8mm" content-width="scale-to-fit" src='{concat("url(&apos;crimage://", /report/licenseeInfo/logoPathLabel, "&apos;)")}' />
                                      </fo:inline>
                                    </fo:block>
                                  </xsl:when>
                                  <xsl:otherwise>
                                    <fo:block font-size="4.5mm" font-weight="bold" font-style="italic">
                                      <xsl:value-of select="/report/licenseeInfo/name" />
                                    </fo:block>
                                  </xsl:otherwise>
                                </xsl:choose>
															</fo:table-cell>
															<fo:table-cell>
																<fo:block>
																	<fo:table width="100%">
																		<fo:table-body>
																			<fo:table-row>
																				<fo:table-cell>
																					<fo:block font-size="2.5mm" text-align="right">
																						<xsl:value-of select="/report/licenseeInfo/phone" />
																					</fo:block>
																				</fo:table-cell>
																			</fo:table-row>
																			<fo:table-row>
																				<fo:table-cell>
																					<fo:block font-size="2.5mm" text-align="right" font-style="italic">
																						<xsl:value-of select="/report/licenseeInfo/httpAddress" />
																					</fo:block>
																				</fo:table-cell>
																			</fo:table-row>
																		</fo:table-body>
																	</fo:table>
																</fo:block>
															</fo:table-cell>
														</fo:table-row>
													</fo:table-body>
												</fo:table>
											</fo:block>

											<!-- Sender box -->
											<fo:block font-size="3mm" border-style="solid" border-width="thin" padding="1mm" wrap-option="no-wrap" overflow="hidden">
												<fo:block font-size="2mm" font-style="italic">
													<xsl:value-of select="/report/lblSender" />
												</fo:block>
												<xsl:choose>
													<xsl:when test="printSenderLogo = 'true'">
														<fo:block text-align="center">
															<fo:inline>
																<fo:external-graphic width="70mm" height="18mm" content-width="scale-to-fit" content-height="scale-to-fit" src="url('logo://expedit')" />
															</fo:inline>
														</fo:block>
													</xsl:when>
													<xsl:otherwise>
														<fo:block text-align="center" wrap-option="wrap" font-weight="bold" font-style="normal">
															<!-- <xsl:call-template name="forcedWrapText"> <xsl:with-param name="data" select="sender/name" /> </xsl:call-template> -->
															<xsl:value-of select="sender/name" />
														</fo:block>
														<fo:block text-align="center" wrap-option="wrap">
															<!-- <xsl:call-template name="forcedWrapText"> <xsl:with-param name="data" select="sender/address" /> </xsl:call-template> -->
															<xsl:value-of select="sender/address" />
														</fo:block>
														<fo:block text-align="center">
															<xsl:value-of select="sender/countryCode" />
															<xsl:text> </xsl:text>
															<xsl:value-of select="sender/postalCode" />
															<xsl:text>, </xsl:text>
															<xsl:value-of select="sender/city" />
														</fo:block>
														<xsl:choose>
															<xsl:when test="string-length(sender/phone) = 0">
																<fo:block font-size="2.75mm">
																	<xsl:text> </xsl:text>
																</fo:block>
															</xsl:when>
															<xsl:otherwise>
																<fo:block text-align="center" margin-left="0mm" font-size="2.75mm">
																	<fo:inline padding-right="1mm">
																		<fo:external-graphic height="3mm" content-width="scale-to-fit" src="url('image://FOP_ICON_PHONE')" />
																	</fo:inline>
																	<xsl:value-of select="sender/phone" />
																</fo:block>
															</xsl:otherwise>
														</xsl:choose>
													</xsl:otherwise>
												</xsl:choose>
											</fo:block>

											<!-- Barcode postal code -->
											<fo:block padding="0.1mm" text-align="center">
												<xsl:call-template name="barcode">
													<xsl:with-param name="codeType" select="'postalCode'" />
													<xsl:with-param name="message" select="receiver/postalCode" />
												</xsl:call-template>
											</fo:block>

											<!-- Receiver box -->
											<fo:block-container>
												<fo:block font-size="3mm" border-style="solid" border-width="thin" padding="1mm" wrap-option="no-wrap" overflow="hidden">
												<xsl:choose>
													<xsl:when test="parcelShop = 'true'">
													<fo:block font-size="2mm" font-style="italic" font-weight="bold">
														<xsl:value-of select="/report/lblReceiver" />
														<xsl:text> - PARCEL SHOP</xsl:text>
													</fo:block>
													</xsl:when>
													<xsl:otherwise>
													<fo:block font-size="2mm" font-style="italic">
														<xsl:value-of select="/report/lblReceiver" />
													</fo:block>
													</xsl:otherwise>
												</xsl:choose>
													<fo:block text-align="center" wrap-option="wrap" font-weight="bold" font-style="normal">
														<!-- <xsl:call-template name="forcedWrapText"> <xsl:with-param name="data" select="receiver/name" /> </xsl:call-template> -->
														<xsl:value-of select="receiver/name" />
													</fo:block>
													<fo:block text-align="center" wrap-option="wrap">
														<!-- <xsl:call-template name="forcedWrapText"> <xsl:with-param name="data" select="receiver/address" /> </xsl:call-template> -->
														<xsl:value-of select="receiver/address" />
													</fo:block>
													<fo:block text-align="center">
														<xsl:value-of select="receiver/countryCode" />
														<xsl:text> </xsl:text>
														<xsl:value-of select="receiver/postalCode" />
														<xsl:text>, </xsl:text>
														<xsl:value-of select="receiver/city" />
													</fo:block>
													<fo:block text-align="center" margin-left="0mm" font-size="2.75mm">
														<fo:inline padding-right="1mm">
															<fo:external-graphic height="2.75mm" content-width="scale-to-fit" src="url('image://FOP_ICON_PHONE')" />
														</fo:inline>
														<xsl:value-of select="receiver/phone" />
													</fo:block>
												</fo:block>
												<!-- 
												<xsl:choose>
													<xsl:when test="parcelShop = 'true'">
														<fo:block-container absolute-position="absolute">
															<fo:block text-align="right" padding-right="0.5mm" padding-top="0.5mm">
																<fo:external-graphic height="5mm" content-width="scale-to-fit" src="url('image://FOP_ICON_PP')" />
															</fo:block>
														</fo:block-container>
													</xsl:when>
												</xsl:choose>
												-->
											</fo:block-container>

											<!-- Barcode multifunctional code -->
											<fo:block padding="0.1mm" text-align="center">
												<xsl:call-template name="barcode">
													<xsl:with-param name="codeType" select="'multifunctional'" />
													<xsl:with-param name="message" select="multifunctionalCode" />
												</xsl:call-template>
											</fo:block>

											<!-- Contact person and sender -->
											<fo:block padding="0" padding-top="0.4mm" padding-bottom="0.3mm" wrap-option="no-wrap" overflow="hidden">
												<fo:table width="100%">
													<fo:table-body>
														<fo:table-row>
															<fo:table-cell>
																<fo:block font-size="2mm">
																	<xsl:value-of select="/report/lblReceiver" />
																	<xsl:text> - </xsl:text>
																	<xsl:value-of select="/report/lblContactPerson" />
																</fo:block>
															</fo:table-cell>
															<fo:table-cell>
																<fo:block font-size="2mm">
																	<xsl:value-of select="/report/lblSender" />
																	<xsl:text> - </xsl:text>
																	<xsl:value-of select="/report/lblContactPerson" />
																</fo:block>
															</fo:table-cell>
														</fo:table-row>
														<fo:table-row>
															<fo:table-cell>
																<fo:block font-size="2.5mm">
																	<xsl:value-of select="receiverContactPerson" />
																</fo:block>
															</fo:table-cell>
															<fo:table-cell>
																<fo:block font-size="2.5mm">
																	<xsl:value-of select="senderContactPerson" />
																</fo:block>
															</fo:table-cell>
														</fo:table-row>
													</fo:table-body>
												</fo:table>
											</fo:block>
											<!-- Delivery remark -->
											<fo:block padding="0.1mm" overflow="hidden">
												<fo:table width="100%">
													<fo:table-body>
														<fo:table-row>
															<fo:table-cell>
																<fo:block font-size="{$stickerFldDelyRemarkFontSize}" font-style="normal" font-weight="{$stickerFldDelyRemarkFontWeight}" wrap-option="wrap">
																	<fo:inline font-weight="bold">
																		<xsl:value-of select="/report/lblDeliveryRemark" />
																		<xsl:text>: </xsl:text>
																	</fo:inline>
																	<xsl:call-template name="forcedWrapText">
																		<xsl:with-param name="data" select="deliveryRemark" />
																	</xsl:call-template>
																</fo:block>
															</fo:table-cell>
														</fo:table-row>
													</fo:table-body>
												</fo:table>
											</fo:block>

										</fo:table-cell>

									</fo:table-row>
								</fo:table-body>
							</fo:table>
						</fo:block>
					</fo:table-cell>

					<!-- Right column -->

					<fo:table-cell margin="0" margin-left="3.5mm" padding="0">
						<fo:block padding="0" margin="0">
							<fo:table width="100%">
								<fo:table-body>
									<fo:table-row>
										<fo:table-cell height="18mm" padding="0" margin="0">
											<fo:block padding="0" margin="0">
												<xsl:call-template name="barcode">
													<xsl:with-param name="message" select="trackingCode" />
													<xsl:with-param name="codeType" select="'trackingCode'" />
												</xsl:call-template>
											</fo:block>
											<fo:block padding="0" padding-top="-1mm" margin="0" font-size="4mm" text-align="center">
												<xsl:value-of select="substring(trackingCode, 1, 6)" />
												<xsl:text> </xsl:text>
												<fo:inline font-weight="bold">
													<xsl:value-of select="substring(trackingCode, 7, 8)" />
												</fo:inline>
												<xsl:text> </xsl:text>
												<xsl:value-of select="substring(trackingCode, 15, 2)" />
											</fo:block>
										</fo:table-cell>
									</fo:table-row>

									<fo:table-row>
										<!-- Reference box and services will be stored in additional table with fixed height as, reference size may vary as well as services list -->
										<fo:table-cell height="36mm" margin="0" padding="0">
											<fo:block>
												<fo:table width="100%">
													<fo:table-body>

														<!-- Reference box -->
														<fo:table-row>
															<fo:table-cell>
																<fo:block border-style="solid" border-width="thin" margin="0" margin-bottom="1mm" padding="0" font-size="2mm">
																	<fo:table width="100%">
																		<fo:table-column column-width="30%" />
																		<fo:table-column column-width="70%" />
																		<fo:table-body>
																			<fo:table-row>
																				<fo:table-cell padding="0.25mm">
																					<fo:block><xsl:value-of select="/report/datum/label" /></fo:block>
																				</fo:table-cell>
																				<fo:table-cell padding="0.25mm">
																					<fo:block><xsl:value-of select="datum" /></fo:block>
																				</fo:table-cell>
																			</fo:table-row>
																			<fo:table-row>
																				<fo:table-cell padding="0.25mm">
																					<fo:block><xsl:value-of select="/report/weight/label" /></fo:block>
																				</fo:table-cell>
																				<fo:table-cell padding="0.25mm">
																					<fo:block><xsl:value-of select="weight" /></fo:block>
																				</fo:table-cell>
																			</fo:table-row>
																			<fo:table-row>
																	<xsl:call-template name="referenceFieldConditional">
																		<xsl:with-param name="optionXPathPrintStickerRefAsBarcode" select="/report/printStickerRef1FldAsBarcode" />
																		<xsl:with-param name="optionXPathReferenceLabel" select="/report/lblReferenceNr1Short" />
																		<xsl:with-param name="fieldReferenceBarcode" select="referenceNr1Barcode" />
																		<xsl:with-param name="fieldReferenceText" select="referenceNr1" />
																		<xsl:with-param name="maxLengthAllowed" select="14" />
																	</xsl:call-template>
																			</fo:table-row>
																			<fo:table-row>
																	<xsl:call-template name="referenceFieldConditional">
																		<xsl:with-param name="optionXPathPrintStickerRefAsBarcode" select="/report/printStickerRef2FldAsBarcode" />
																		<xsl:with-param name="optionXPathReferenceLabel" select="/report/lblReferenceNr2Short" />
																		<xsl:with-param name="fieldReferenceBarcode" select="referenceNr2Barcode" />
																		<xsl:with-param name="fieldReferenceText" select="referenceNr2" />
																		<xsl:with-param name="maxLengthAllowed" select="14" />
																	</xsl:call-template>
																			</fo:table-row>
																			<fo:table-row>
																	<xsl:call-template name="referenceFieldConditional">
																		<xsl:with-param name="optionXPathPrintStickerRefAsBarcode" select="/report/printStickerRef3FldAsBarcode" />
																		<xsl:with-param name="optionXPathReferenceLabel" select="/report/lblReferenceNr3Short" />
																		<xsl:with-param name="fieldReferenceBarcode" select="referenceNr3Barcode" />
																		<xsl:with-param name="fieldReferenceText" select="referenceNr3" />
																		<xsl:with-param name="maxLengthAllowed" select="14" />
																	</xsl:call-template>
																			</fo:table-row>
																			<xsl:choose>
																				<xsl:when test="/report/printVehicleInfo = 'true'">
																					<fo:table-row>
																						<fo:table-cell padding="0.25mm">
																							<fo:block><xsl:text>Vozilo br.</xsl:text></fo:block>
																						</fo:table-cell>
																						<fo:table-cell padding="0.25mm">
																							<fo:block><xsl:value-of select="/report/vehicleInfo" /></fo:block>
																						</fo:table-cell>
																					</fo:table-row>
																				</xsl:when>
																			</xsl:choose>
																		</fo:table-body>
																	</fo:table>
																</fo:block>
															</fo:table-cell>
														</fo:table-row>

														<!-- Services -->
														<fo:table-row>
															<fo:table-cell>
																<fo:block margin-top="2mm" margin-bottom="1mm">
																	<fo:table width="100%">
																		<fo:table-body>
																			<fo:table-row>
																				<fo:table-cell>
																					<fo:block font-size="2mm">
																						<xsl:value-of select="/report/lblServices" />
																					</fo:block>
																				</fo:table-cell>
																			</fo:table-row>
																			<fo:table-row>
																				<fo:table-cell>
																					<fo:block font-size="3.5mm" font-weight="bold" font-style="normal" margin-top="0.5mm">
																						<xsl:value-of select="servicesDescriptor" />
																					</fo:block>
																				</fo:table-cell>
																			</fo:table-row>
																		</fo:table-body>
																	</fo:table>
																</fo:block>
															</fo:table-cell>
														</fo:table-row>
													</fo:table-body>
												</fo:table>
											</fo:block>
										</fo:table-cell>
									</fo:table-row>

									<!-- Routing info -->
									<fo:table-row>
										<fo:table-cell>
											<fo:block margin="0" padding="0">
												<fo:table width="100%">
													<fo:table-body>
														<fo:table-row>
															<fo:table-cell>
																<fo:block font-size="4mm" font-weight="normal" text-align="right" padding-top="1mm">
																	<xsl:value-of select="routingSourceCenterAbbr" />
																</fo:block>
															</fo:table-cell>
															<fo:table-cell>
																<fo:block font-size="9.5mm" font-weight="bold" padding-left="4mm">
																	<xsl:value-of select="routingDestCenterAbbr" />
																</fo:block>
																<fo:block font-size="9mm" font-weight="bold" padding-left="4mm" padding-top="-2mm" margin-bottom="-3mm">
																	<xsl:text> </xsl:text>
																	<xsl:value-of select="routeNumber" />
																</fo:block>
															</fo:table-cell>
														</fo:table-row>
													</fo:table-body>
												</fo:table>
											</fo:block>
										</fo:table-cell>
									</fo:table-row>

								</fo:table-body>
							</fo:table>
						</fo:block>

					</fo:table-cell>
				</fo:table-row>

				<!-- Footer -->
				<fo:table-row>
					<fo:table-cell>
						<fo:block></fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block font-size="2mm">
							<xsl:value-of select="/report/licenseeInfo/shortDescription" />
						</fo:block>
						<fo:block font-size="1.5mm">
							<xsl:value-of select="/report/expeditInfo/name" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell margin="0">
						<fo:block font-size="2.7mm" text-align="right" padding-right="4mm">
							<xsl:value-of select="formattedPacketNumber" />
						</fo:block>
					</fo:table-cell>
				</fo:table-row>

			</fo:table-body>
		</fo:table>
	</xsl:template>

	<xsl:template name="separator_horizontal">
		<fo:block width="100%" height="1px">
			<fo:table width="100%" height="1px">
				<fo:table-body>
					<fo:table-row>
						<fo:table-cell width="10mm" height="0px" padding="0" border-top-style="solid" border-top-width="thin" border-top-color="#555555">
							<fo:block width="10mm" height="0px"></fo:block>
						</fo:table-cell>
						<fo:table-cell padding="0">
							<fo:block width="1px" height="1px"></fo:block>
						</fo:table-cell>
						<fo:table-cell width="10mm" height="0px" padding="0" border-top-style="solid" border-top-width="thin" border-top-color="#555555">
							<fo:block width="10mm" height="0px"></fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-body>
			</fo:table>
		</fo:block>
	</xsl:template>

	<xsl:template name="separator_vertical">
		<fo:block width="1px" height="97mm">
			<fo:table width="1px" height="97mm">
				<fo:table-body>
					<fo:table-row>
						<fo:table-cell width="0" height="10mm" padding="0" border-left-style="solid" border-left-width="thin" border-left-color="#555555">
							<fo:block width="0" height="0"></fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell width="0" height="71mm" padding="0">
							<fo:block width="1px" height="71mm"></fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell width="0" height="10mm" padding="0" border-left-style="solid" border-left-width="thin" border-left-color="#555555">
							<fo:block width="0" height="0"></fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell width="0" height="6mm" padding="0">
							<fo:block width="1px" height="6mm"></fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-body>
			</fo:table>
		</fo:block>
	</xsl:template>

	<xsl:template name="forcedWrapText">
		<xsl:param name="data" />
		<xsl:param name="counter" select="0" />
		<xsl:choose>
			<xsl:when test="$counter &lt;= string-length($data)">
				<xsl:value-of select='concat(substring($data,$counter,1),"​")' />
				<xsl:call-template name="internalForcedWrapText">
					<xsl:with-param name="data" select="$data" />
					<xsl:with-param name="counter" select="$counter+1" />
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="internalForcedWrapText">
		<xsl:param name="data" />
		<xsl:param name="counter" />
		<xsl:value-of select='concat(substring($data,$counter,1),"​")' />
		<xsl:call-template name="forcedWrapText">
			<xsl:with-param name="data" select="$data" />
			<xsl:with-param name="counter" select="$counter+1" />
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="referenceFieldConditional">
		<xsl:param name="optionXPathPrintStickerRefAsBarcode" />
		<xsl:param name="optionXPathReferenceLabel" />
		<xsl:param name="fieldReferenceBarcode" />
		<xsl:param name="fieldReferenceText" />
		<xsl:param name="maxLengthAllowed" />
		<xsl:choose>
			<xsl:when test="$optionXPathPrintStickerRefAsBarcode = 'true' and string-length($fieldReferenceBarcode) &gt; 0 and string-length($fieldReferenceBarcode) &lt;= $maxLengthAllowed">
				<fo:table-cell padding="0.25mm" padding-left="1.5mm" wrap-option="no-wrap" display-align="center" number-columns-spanned="2">
					<fo:block>
						<fo:inline>
							<xsl:call-template name="barcode">
								<xsl:with-param name="message" select="$fieldReferenceBarcode" />
								<xsl:with-param name="codeType" select="'rRef1'" />
							</xsl:call-template>
						</fo:inline>
					</fo:block>
					<fo:block wrap-option="wrap">
						<xsl:call-template name="forcedWrapText">
							<xsl:with-param name="data" select="$fieldReferenceText" />
						</xsl:call-template>
					</fo:block>
				</fo:table-cell>
			</xsl:when>
			<xsl:otherwise>
				<fo:table-cell padding="0.25mm" wrap-option="no-wrap" display-align="center">
					<fo:block>
						<xsl:value-of select="$optionXPathReferenceLabel" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell padding="0.25mm">
					<!-- fo:block wrap-option="wrap" font-size="2.8mm" -->
					<fo:block wrap-option="wrap">
						<xsl:call-template name="forcedWrapText">
							<xsl:with-param name="data" select="$fieldReferenceText" />
						</xsl:call-template>
					</fo:block>
				</fo:table-cell>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>


	<!-- ============================== -->
	<!-- Template: Single Empty Sticker -->
	<!-- ============================== -->

	<xsl:template name="sticker_empty">
		<xsl:choose>
			<xsl:when test="/report/demo = 'true'">
				<fo:block background-image="url('image://FOP_DEMO')" background-position="0,0" background-repeat="repeat" background-color="white" padding="3mm">
					<xsl:call-template name="sticker_empty_inner"></xsl:call-template>
				</fo:block>
			</xsl:when>
			<xsl:otherwise>
				<fo:block padding="3mm">
					<xsl:call-template name="sticker_empty_inner"></xsl:call-template>
				</fo:block>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="sticker_empty_inner">
		<fo:table width="100%">
			<fo:table-column column-width="130mm" />
			<fo:table-body>
				<fo:table-row height="75mm">
					<fo:table-cell>
						<fo:block>
							<xsl:text> </xsl:text>
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		</fo:table>
	</xsl:template>

</xsl:stylesheet>

