<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:java="java"
	exclude-result-prefixes="fo"
>

	<xsl:output method="xml" version="1.0" omit-xml-declaration="no" indent="no" />

	<xsl:param name="body.font.family" expression="Arial, FreeSans" />
	<xsl:param name="title.font.family" expression="Arial, FreeSans" />
	<xsl:param name="monospace.font.family" expression="Arial, FreeSans" />
	<!-- <xsl:param name="body.font.master" select="'10.1'" /> -->
	<xsl:param name="symbol.font.family" expression="Arial, FreeSans" />
	<xsl:param name="body.fontset" expression="Arial, FreeSans" />

	<xsl:include href="template://Barcode_Template.xsl" />

	<!-- ============================== -->
	<!-- Template: Report A4 Landscape -->
	<!-- ============================== -->

	<xsl:template match="report">
		<fo:root font-family="Arial, FreeSans">
			<fo:layout-master-set>
				<fo:simple-page-master master-name="whole_page" page-width="297mm" page-height="210mm" margin-top="5mm" margin-bottom="5mm" margin-left="10mm"
					margin-right="10mm"
				>
					<xsl:choose>
						<xsl:when test="/report/demo = 'true'">
							<fo:region-body margin-left="0" margin-right="0" margin-top="26mm" margin-bottom="13mm" background-image="url('image://FOP_DEMO')" background-position="0,0"
								background-repeat="repeat" background-color="white" />
						</xsl:when>
						<xsl:otherwise>
							<fo:region-body margin-left="0" margin-right="0" margin-top="26mm" margin-bottom="13mm" />
						</xsl:otherwise>
					</xsl:choose>
					<fo:region-before extent="25mm" />
					<fo:region-after extent="10mm" />
				</fo:simple-page-master>
			</fo:layout-master-set>

			<fo:page-sequence master-reference="whole_page" initial-page-number="{/report/startingPageNumber}">

				<fo:static-content flow-name="xsl-region-before">
					<!-- Header begin -->
					<fo:block>
						<fo:table width="100%">
							<fo:table-body>
								<fo:table-row>
									<fo:table-cell>
										<!-- Company info -->

										<!-- Barcode CargoNetID -->
										<xsl:choose>
											<xsl:when test="string-length(/report/registeredCustomerInfo/cargoNetID) > 0">
												<fo:block padding="0.1mm" text-align="left">
													<xsl:call-template name="barcode">
														<xsl:with-param name="message" select="/report/registeredCustomerInfo/cargoNetID" />
														<xsl:with-param name="codeType" select="'rcid'" />
													</xsl:call-template>
												</fo:block>
												<fo:block font-size="3mm" padding-top="-1mm">
													<xsl:text>ID: </xsl:text>
													<xsl:value-of select="/report/registeredCustomerInfo/cargoNetID" />
												</fo:block>
											</xsl:when>
											<xsl:otherwise>
												<fo:block font-size="3mm" padding-top="-1mm">
													<xsl:text>id: ______</xsl:text>
												</fo:block>
											</xsl:otherwise>
										</xsl:choose>

										<fo:block font-size="4mm" font-weight="bold" font-style="italic" text-align="left" wrap-option="wrap">
											<xsl:value-of select="/report/registeredCustomerInfo/name" />
										</fo:block>
										<fo:block font-size="2.5mm" text-align="left" wrap-option="wrap">
											<xsl:value-of select="/report/registeredCustomerInfo/address" />
											<xsl:text>, </xsl:text>
											<xsl:value-of select="/report/registeredCustomerInfo/postalCode" />
											<xsl:text> </xsl:text>
											<xsl:value-of select="/report/registeredCustomerInfo/city" />
										</fo:block>
										<fo:block font-size="3mm" font-style="italic" text-align="left" wrap-option="wrap">
											<xsl:value-of select="/report/registeredCustomerInfo/accountType" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell>
										<!-- Report header -->
										<fo:block font-size="5mm" font-weight="bold" text-align="center" wrap-option="wrap" margin-bottom="2mm">
											<xsl:value-of select="/report/lblReportTitle" />
										</fo:block>
										<fo:block font-size="3.5mm" text-align="center">
											<fo:table width="100%">
												<fo:table-body>
													<fo:table-row>
														<fo:table-cell padding-right="2mm">
															<fo:block font-style="italic" text-align="right">
																<xsl:value-of select="/report/center/label" />
																<xsl:text>:</xsl:text>
															</fo:block>
														</fo:table-cell>
														<fo:table-cell>
															<fo:block font-weight="bold" text-align="left" wrap-option="no-wrap">
																<xsl:value-of select="/report/center/value" />
															</fo:block>
														</fo:table-cell>
													</fo:table-row>
													<fo:table-row>
														<fo:table-cell padding-right="2mm">
															<fo:block font-style="italic" text-align="right">
																<xsl:value-of select="/report/datum/label" />
																<xsl:text>: </xsl:text>
															</fo:block>
														</fo:table-cell>
														<fo:table-cell>
															<fo:block font-weight="bold" text-align="left" wrap-option="no-wrap">
																<xsl:value-of select="/report/datum/value" />
															</fo:block>
														</fo:table-cell>
													</fo:table-row>
												</fo:table-body>
											</fo:table>
										</fo:block>
									</fo:table-cell>
									<fo:table-cell>
										<!-- Licensee logo -->
										<xsl:choose>
											<xsl:when test="/report/printLicenseeLogoOnLabel = 'true'">
												<fo:block text-align="right">
													<fo:inline padding-right="0mm">
														<fo:external-graphic height="9mm" content-width="scale-to-fit" src='{concat("url(&apos;crimage://", /report/licenseeInfo/logoPathLabel, "&apos;)")}' />
													</fo:inline>
													<fo:block font-size="2.2mm" text-align="right" wrap-option="no-wrap">
														<xsl:value-of select="/report/licenseeInfo/address" />
														<xsl:text>, </xsl:text>
														<xsl:value-of select="/report/licenseeInfo/postalCode" />
														<xsl:text> </xsl:text>
														<xsl:value-of select="/report/licenseeInfo/city" />
													</fo:block>
													<fo:block font-size="2.2mm" text-align="right" font-style="italic" wrap-option="no-wrap">
														<xsl:value-of select="/report/licenseeInfo/httpAddress" />
													</fo:block>
												</fo:block>
											</xsl:when>
											<xsl:otherwise>
												<fo:block font-size="4mm" font-weight="bold" font-style="italic" text-align="right" wrap-option="wrap">
													<xsl:value-of select="/report/licenseeInfo/name" />
												</fo:block>
												<fo:block font-size="2.5mm" text-align="right" wrap-option="wrap">
													<xsl:value-of select="/report/licenseeInfo/address" />
													<xsl:text>, </xsl:text>
													<xsl:value-of select="/report/licenseeInfo/postalCode" />
													<xsl:text> </xsl:text>
													<xsl:value-of select="/report/licenseeInfo/city" />
												</fo:block>
												<fo:block font-size="2.5mm" text-align="right" font-style="italic" wrap-option="wrap">
													<xsl:value-of select="/report/licenseeInfo/httpAddress" />
												</fo:block>
											</xsl:otherwise>
										</xsl:choose>
									</fo:table-cell>
								</fo:table-row>
							</fo:table-body>
						</fo:table>
					</fo:block>
					<!-- Header end -->
				</fo:static-content>

				<fo:static-content flow-name="xsl-region-after">
					<!-- Footer begin -->
					<fo:block padding-top="1mm" border-style="solid" border-width="0" border-top-width="thin">
						<fo:table width="100%">
							<fo:table-body>
								<fo:table-row>
									<fo:table-cell>
										<fo:block font-size="2.5mm" text-align="left" wrap-option="wrap">
											<xsl:value-of select="/report/licenseeInfo/shortDescription" />
										</fo:block>
										<fo:block font-size="2mm" text-align="left" font-style="italic" wrap-option="wrap">
											<xsl:value-of select="/report/expeditInfo/name" />
											<!-- <xsl:text>, </xsl:text> <xsl:value-of select="/report/expeditInfo/httpAddress" /> -->
										</fo:block>
									</fo:table-cell>
									<fo:table-cell>
										<fo:block font-size="3mm" text-align="right" wrap-option="wrap">
											<xsl:value-of select="/report/lblPage" />
											<xsl:text> </xsl:text>
											<fo:page-number />
											<!-- <xsl:text> </xsl:text> <xsl:value-of select="/report/pageOfLabel" /> <xsl:text> </xsl:text> <fo:page-number-citation ref-id="endOfDocument" /> -->
										</fo:block>
									</fo:table-cell>
								</fo:table-row>
							</fo:table-body>
						</fo:table>
					</fo:block>
					<!-- Footer end -->
				</fo:static-content>

				<fo:flow flow-name="xsl-region-body">
					<fo:block>
						<!-- Main content begin -->
						<xsl:for-each select="shipmentsInfo/shipmentInfo">
							<fo:block padding-top="1mm" padding-bottom="1mm" border-style="solid" border-width="0" border-top-width="thin">
								<xsl:apply-templates select="." />
							</fo:block>
						</xsl:for-each>
						<!-- Main content end -->

						<xsl:choose>
							<xsl:when test="/report/documentSectionLast = 'true'">

								<!-- Signatures part begin -->
								<fo:footnote keep-with-previous="always">
									<fo:inline />
									<fo:footnote-body>
										<fo:block padding-top="2mm">
											<fo:table width="100%">
												<fo:table-body>
													<fo:table-row>
														<fo:table-cell width="70mm" margin-right="5mm">
															<fo:block font-size="3mm" text-align="left" wrap-option="wrap" margin-bottom="0.5mm">
																<xsl:value-of select="/report/lblCurrierSignature" />
															</fo:block>
															<fo:block border-style="solid" line-height="12mm" border-width="thin" color="#FFFFFF">
																<xsl:text>.</xsl:text>
															</fo:block>
															<fo:block font-size="2.5mm" wrap-option="wrap" margin-top="0.4mm" color="#FFFFFF">
																<xsl:text>.</xsl:text>
															</fo:block>
														</fo:table-cell>
														<fo:table-cell width="70mm" margin-right="5mm">
															<fo:block font-size="3mm" text-align="left" wrap-option="wrap" margin-bottom="0.5mm">
																<xsl:value-of select="/report/lblSenderSignature" />
															</fo:block>
															<fo:block border-style="solid" line-height="12mm" border-width="thin" color="#FFFFFF">
																<xsl:text>.</xsl:text>
															</fo:block>
															<fo:block font-size="2.5mm" text-align="right" font-style="italic" wrap-option="wrap" margin-top="0.4mm">
																<xsl:value-of select="/report/lblFor" />
																<xsl:text> "</xsl:text>
																<xsl:value-of select="/report/registeredCustomerInfo/name" />
																<xsl:text>" (</xsl:text>
																<xsl:value-of select="/report/registeredCustomerInfo/accountType" />
																<xsl:text>)</xsl:text>
															</fo:block>
														</fo:table-cell>
														<fo:table-cell display-align="center">
															<fo:block font-size="2.5mm" text-align="left" margin="1mm">
																<xsl:value-of select="/report/lblAgreementText" />
															</fo:block>
															<fo:block font-size="2.5mm" wrap-option="wrap" margin-top="0.4mm" color="#FFFFFF">
																<xsl:text>.</xsl:text>
															</fo:block>
														</fo:table-cell>
														<fo:table-cell width="40mm" margin-left="5mm">
															<fo:block font-size="4mm" font-weight="bold" text-decoration="underline" text-align="right" wrap-option="wrap" margin-bottom="0.5mm">
																<xsl:value-of select="/report/numberOfParcels/label" />
																<xsl:text>: </xsl:text>
																<xsl:value-of select="/report/numberOfParcels/value" />
															</fo:block>
														</fo:table-cell>
													</fo:table-row>
												</fo:table-body>
											</fo:table>
										</fo:block>
									</fo:footnote-body>
								</fo:footnote>
								<!-- Signatures part end -->

							</xsl:when>
							<xsl:otherwise>
							</xsl:otherwise>
						</xsl:choose>

					</fo:block>
				</fo:flow>

			</fo:page-sequence>
		</fo:root>
	</xsl:template>

	<xsl:template match="shipmentInfo">
		<fo:table width="100%">
			<fo:table-body>
				<fo:table-row>
					<!-- Cannot use keep-together="always" here, otherwise forced wrap will not work -->
					<!-- NOTICE: -->
					<!-- keep-together="always" implicitly sets keep-together.within-line="always" which basically forbids line breaking. -->
					<!-- Use keep-together.within-column="always" instead -->
					<fo:table-cell keep-together="always">
						<fo:block font-size="2.5mm" text-align="left" wrap-option="wrap">
							<fo:table width="100%">
								<fo:table-column column-width="40mm" />
								<fo:table-column column-width="45mm" />
								<fo:table-column />
								<fo:table-column column-width="35mm" />
								<fo:table-body>
									<fo:table-row>

										<!-- Sender info -->
										<fo:table-cell wrap-option="wrap" padding-right="3mm">
											<fo:block font-size="2.5mm" text-align="left" wrap-option="wrap">
												<xsl:value-of select="/report/lblReferenceNr1Short" />
											</fo:block>
											<fo:block keep-with-previous.within-page="always" keep-together.within-line="auto" keep-together.within-column="always" wrap-option="wrap" margin-bottom="1mm">
												<xsl:call-template name="forcedWrapText">
													<xsl:with-param name="data" select="referenceNr1" />
												</xsl:call-template>
											</fo:block>
											<fo:block font-size="2.5mm" text-align="left" wrap-option="wrap" keep-with-previous.within-page="always">
												<xsl:value-of select="/report/lblSender" />
											</fo:block>
											<fo:block font-size="3mm" text-align="left" wrap-option="wrap" keep-with-previous.within-page="always">
												<xsl:call-template name="forcedWrapText">
													<xsl:with-param name="data" select="sender/name" />
												</xsl:call-template>
											</fo:block>
											<fo:block font-size="3mm" text-align="left" wrap-option="wrap" keep-with-previous.within-page="always">
												<xsl:call-template name="forcedWrapText">
													<xsl:with-param name="data" select="sender/address" />
												</xsl:call-template>
											</fo:block>
											<fo:block font-size="3mm" text-align="left" wrap-option="wrap" keep-with-previous.within-page="always">
												<xsl:value-of select="sender/postalCode" />
												<xsl:text> </xsl:text>
												<xsl:call-template name="forcedWrapText">
													<xsl:with-param name="data" select="sender/city" />
												</xsl:call-template>
											</fo:block>
										</fo:table-cell>

										<!-- Receiver info -->
										<!-- <fo:table-cell width="45mm"> -->
										<fo:table-cell width="45mm">
											<fo:block font-size="2.5mm" text-align="left">
												<xsl:value-of select="/report/lblReceiver" />
											</fo:block>
											<fo:block font-size="3mm" text-align="left" wrap-option="wrap" font-weight="bold" keep-with-previous.within-page="always">
												<xsl:call-template name="forcedWrapText">
													<xsl:with-param name="data" select="receiver/name" />
												</xsl:call-template>
											</fo:block>
											<fo:block font-size="3mm" text-align="left" wrap-option="wrap" keep-with-previous.within-page="always">
												<xsl:call-template name="forcedWrapText">
													<xsl:with-param name="data" select="receiver/address" />
												</xsl:call-template>
											</fo:block>
											<fo:block font-size="3mm" text-align="left" wrap-option="wrap" keep-with-previous.within-page="always">
												<xsl:value-of select="receiver/postalCode" />
												<xsl:text> </xsl:text>
												<xsl:call-template name="forcedWrapText">
													<xsl:with-param name="data" select="receiver/city" />
												</xsl:call-template>
											</fo:block>
											<xsl:choose>
												<xsl:when test="receiver/countryCode = 'SK'">
												</xsl:when>
												<xsl:otherwise>
													<fo:block font-size="3mm" text-align="left" wrap-option="wrap" keep-with-previous.within-page="always">
														<xsl:call-template name="forcedWrapText">
															<xsl:with-param name="data" select="receiver/countryName" />
														</xsl:call-template>
													</fo:block>
												</xsl:otherwise>
											</xsl:choose>
											<xsl:choose>
												<xsl:when test="string-length(receiver/phone) = 0">
												</xsl:when>
												<xsl:otherwise>
													<fo:block font-size="2.8mm" text-align="left" wrap-option="wrap" keep-with-previous.within-page="always">
														<fo:inline padding-right="0.7mm">
															<fo:external-graphic height="2.3mm" content-width="scale-to-fit" src="url('image://FOP_ICON_PHONE')" />
														</fo:inline>
														<xsl:call-template name="forcedWrapText">
															<xsl:with-param name="data" select="receiver/phone" />
														</xsl:call-template>
													</fo:block>
												</xsl:otherwise>
											</xsl:choose>
											<fo:block font-size="2.5mm" text-align="left" wrap-option="wrap" margin-top="1mm" keep-with-previous.within-page="always">
												<xsl:value-of select="/report/lblContactPerson" />
											</fo:block>
											<fo:block font-size="3mm" text-align="left" wrap-option="wrap" font-weight="bold" keep-with-previous.within-page="always">
												<xsl:call-template name="forcedWrapText">
													<xsl:with-param name="data" select="contactPersonName" />
												</xsl:call-template>
											</fo:block>
										</fo:table-cell>

										<!-- Shipment info -->
										<fo:table-cell>
											<fo:block font-size="2.8mm" text-align="left">
												<xsl:value-of select="concat(/report/lblRemark, ': ', remark)" />
											</fo:block>
											<fo:block font-size="2.8mm" text-align="left" margin-top="0.5mm" keep-with-previous.within-page="always">
												<xsl:value-of select="concat(/report/lblParcelNumber, ': ', numberOfParcels)" />
											</fo:block>
											<fo:block font-size="2.8mm" text-align="left" margin-top="0.5mm" keep-with-previous.within-page="always">
												<xsl:value-of select="concat(/report/lblCashOnDeliveryValue, ': ')" />
												<fo:inline font-weight="bold" font-style="italic">
													<xsl:value-of select="cashOnDeliveryValue" />
												</fo:inline>
											</fo:block>

											<!-- Do not show bill base type for Slovakia -->
											<!-- <fo:block font-size="2.8mm" text-align="left" margin-top="0.5mm" keep-with-previous.within-page="always"> <xsl:value-of select="concat(/report/lblBillBaseType, ': ', 
												billBaseType)" /> </fo:block> -->

											<!-- do not repeat the info if it was displayed already (i.e. number of parcels) -->
											<!-- This will never happen, as the bill base type is fixed on WEIGHT -->
											<!-- <xsl:choose> <xsl:when test="billBaseTypeID != 'NUMBER_OF_PACKAGES'"> -->
											<fo:block font-size="2.8mm" text-align="left" margin-top="0.5mm" keep-with-previous.within-page="always">
												<xsl:value-of select="concat(billBaseType, ': ', weight)" />
											</fo:block>
											<!-- </xsl:when> </xsl:choose> -->

											<fo:block font-size="2.8mm" text-align="left" margin-top="0.5mm" keep-with-previous.within-page="always">
												<xsl:value-of select="concat(/report/lblInsuranceValue, ': ')" />
												<fo:inline font-weight="bold" font-style="italic">
													<xsl:value-of select="insuranceValue" />
												</fo:inline>
											</fo:block>
										</fo:table-cell>

										<!-- Services info -->
										<fo:table-cell width="35mm">
											<xsl:for-each select="service">
												<xsl:choose>
													<xsl:when test="enabled = 'true'">
														<fo:block font-size="2.5mm" font-weight="bold" font-style="italic" text-align="left">
															<fo:inline padding-right="1mm">
																<fo:external-graphic height="2.3mm" content-width="scale-to-fit" src="url('image://FOP_ICON_CHECKED')" />
															</fo:inline>
															<xsl:value-of select="name" />
														</fo:block>
													</xsl:when>
													<xsl:when test="printIfDisabled = 'true'">
														<fo:block font-size="2mm" font-weight="normal" font-style="italic" text-align="left">
															<fo:inline padding-right="1.5mm">
																<fo:external-graphic height="1.9mm" content-width="scale-to-fit" src="url('image://FOP_ICON_UNCHECKED')" />
															</fo:inline>
															<xsl:value-of select="name" />
														</fo:block>
													</xsl:when>
												</xsl:choose>
											</xsl:for-each>
											<!-- No services defined: -->
											<xsl:if test="service">
												<fo:block>
													<xsl:text> </xsl:text>
												</fo:block>
											</xsl:if>
										</fo:table-cell>
									</fo:table-row>
								</fo:table-body>
							</fo:table>
						</fo:block>
					</fo:table-cell>
					<fo:table-cell width="95mm">
						<fo:block>
							<fo:table width="100%">
								<fo:table-body>
									<xsl:for-each select="packetsInfo/packetsRow">
										<fo:table-row>
											<xsl:for-each select="packetCode">
												<fo:table-cell margin-left="3mm">
													<fo:block padding="0" margin="0">
														<xsl:call-template name="barcode">
															<xsl:with-param name="message" select="." />
															<xsl:with-param name="codeType" select="'reportTrackingCode'" />
														</xsl:call-template>
													</fo:block>
													<fo:block padding="0" padding-top="-1mm" margin="0" font-size="3mm" text-align="left" keep-with-previous.within-page="always">
														<xsl:value-of select="substring(., 1, 6)" />
														<xsl:text> </xsl:text>
														<fo:inline font-weight="bold">
															<xsl:value-of select="substring(., 7, 8)" />
														</fo:inline>
														<xsl:text> </xsl:text>
														<xsl:value-of select="substring(., 15, 2)" />
													</fo:block>
												</fo:table-cell>
											</xsl:for-each>
										</fo:table-row>
									</xsl:for-each>
								</fo:table-body>
							</fo:table>
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		</fo:table>
	</xsl:template>

	<xsl:template name="forcedWrapText">
		<xsl:param name="data" />
		<xsl:param name="counter" select="1" />
		<xsl:choose>
			<xsl:when test="$counter &lt;= string-length($data)">
				<xsl:value-of select='concat(substring($data,$counter,1),"&#8203;")' />
				<xsl:call-template name="forcedWrapText">
					<xsl:with-param name="data" select="$data" />
					<xsl:with-param name="counter" select="$counter+1" />
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

</xsl:stylesheet>

